@@ -1,5 +1,5 @@
 use super::config::{default_scope, MATCH_OPTIONS};
-use anyhow::*;
+use anyhow::{Context, Result};
 use git2::{
     build::CheckoutBuilder, BranchType, Commit, Cred, MergeOptions, Object, ObjectType, Oid,
     PushOptions, RebaseOptions, RemoteCallbacks, Repository, ResetType, Signature, TreeWalkMode,
@@ -211,13 +211,13 @@ impl Repo {
         let head_commit = self.inner.head().unwrap().peel_to_commit().unwrap();
         let msg = if scope != default_scope() {
             format!(
-                "[cepler] Updated '{}' state in '{}'",
+                "ci(cepler): Updated '{}' state in '{}'",
                 scope,
                 path.file_stem().unwrap().to_str().unwrap()
             )
         } else {
             format!(
-                "[cepler] Updated '{}' state",
+                "ci(cepler): Updated '{}' state",
                 path.file_stem().unwrap().to_str().unwrap()
             )
         };
